==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DNewMultiArrayExpr.h <==
// public class soot.dava.internal.javaRep.DNewMultiArrayExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 437f191363fff027 soot_dava_internal_javaRep_DNewMultiArrayExpr
// @dep_class f1308ce4deac7989 soot_jimple_internal_AbstractNewMultiArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewMultiArrayExpr

#include "soot/jimple/internal/AbstractNewMultiArrayExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DNewMultiArrayExpr_H_
#define _JC_soot_dava_internal_javaRep_DNewMultiArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_ArrayType$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_refs	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$refs	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$nonrefs	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vmethods	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtable	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method$_init$6d5b986214f5a4a4(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *, struct _jc_soot_ArrayType$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *);
extern void _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewMultiArrayExpr$vmethods	soot_jimple_internal_AbstractNewMultiArrayExpr;
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vmethods	soot_dava_internal_javaRep_DNewMultiArrayExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$refs {
    _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_refs	soot_dava_internal_javaRep_DNewMultiArrayExpr;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_refs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_nonrefs	soot_dava_internal_javaRep_DNewMultiArrayExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object {
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DNewMultiArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DNewMultiArrayExpr_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DNewMultiArrayExpr.h <==
// public class soot.dava.internal.javaRep.DNewMultiArrayExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 437f191363fff027 soot_dava_internal_javaRep_DNewMultiArrayExpr
// @dep_class f1308ce4deac7989 soot_jimple_internal_AbstractNewMultiArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewMultiArrayExpr

#include "soot/jimple/internal/AbstractNewMultiArrayExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DNewMultiArrayExpr_H_
#define _JC_soot_dava_internal_javaRep_DNewMultiArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_ArrayType$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_refs	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$refs	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$nonrefs	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vmethods	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtable	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method$_init$6d5b986214f5a4a4(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *, struct _jc_soot_ArrayType$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewMultiArrayExpr$vmethods	soot_jimple_internal_AbstractNewMultiArrayExpr;
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vmethods	soot_dava_internal_javaRep_DNewMultiArrayExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$refs {
    _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_refs	soot_dava_internal_javaRep_DNewMultiArrayExpr;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_refs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewMultiArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewMultiArrayExpr;
    _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$sub_nonrefs	soot_dava_internal_javaRep_DNewMultiArrayExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$object {
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$vtype _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DNewMultiArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DNewMultiArrayExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DNewMultiArrayExpr_H_ */
